pub fn scan_fleet(
db: &AdvisoryDb,
config: &Config,
toolchain: Option<&Toolchain>,
host_triple: Option<&str>,
go: &GoScan<'_>,
npm: &NpmScan<'_>,
pypi: &PyPiScan<'_>,
rubygems: &RubyGemsScan<'_>,
packagist: &PackagistScan<'_>,
nuget: &NuGetScan<'_>,
julia: &JuliaScan<'_>,
swift: &SwiftScan<'_>,
hex: &HexScan<'_>,
ghactions: &GhActionsScan<'_>,
maven: &MavenScan<'_>,
) -> ScanDataExpand description
Scan every repo in config, plus the toolchain if provided. When
host_triple is Some, each finding is additionally annotated (via
cargo tree) with whether the package is actually built — see
crate::resolve.